from main import *
import functions

class Button(pygame.sprite.Sprite):
    def __init__(self, img, initpos, delay=100):
        pygame.sprite.Sprite.__init__(self)
        self.image = img
        self.rect = self.image.get_rect()
        self.pos = initpos
        self.rect.midbottom = self.pos
        self.delay = delay
        self.last_run = 0
        self.move = 0
        self.speed = 2
        self.time = pygame.time.get_ticks()
    def update(self):
        if pygame.time.get_ticks() > self.last_run + self.delay:
            if self.move >= 2:
                self.speed *= -1
            elif self.move <= -2:
                self.speed *= -1
            self.rect.top += self.speed
            self.move += self.speed
            self.last_run = pygame.time.get_ticks()

class Object(pygame.sprite.Sprite):
    def __init__(self, img, initpos, sound, num):
        pygame.sprite.Sprite.__init__(self)
        self.image = img
        self.rect = self.image.get_rect()
        self.pos = initpos
        self.rect.midbottom = self.pos
        self.button = (0,0,0)
        self.selected = 0
        self.mouseover = False
        self.has_moved = False
        self.speed = 2
        self.acceleration = 1.05
        self.sound_fx = pygame.mixer.Sound(sound)
        self.sound_fx.set_volume(0.5)
        self.id = num
    def rollover(self, balloon):
        mpos = pygame.mouse.get_pos()
        if self.rect.collidepoint(mpos):
            self.mouseover=True
            if self.has_moved == False:
                self.sound_fx.play()
            balloon.kill()
        else:
            self.mouseover=False
    def reset(self):
        self.rect.midbottom = self.pos
        self.has_moved = False
        self.speed = 2      
    def update(self):
        mpos = pygame.mouse.get_pos()
        self.selected = self.rect.collidepoint(mpos)
        if (self.mouseover):
            self.button = pygame.mouse.get_pressed()
            if self.button == (1,0,0):
                self.speed = 2
                pos = pygame.mouse.get_pos()
                self.rect.center = pos
                self.has_moved = True
        if self.has_moved and self.button != (1,0,0):
            if self.rect.top >= 600:
                self.reset()
            else:
                self.rect.top += self.speed
                self.speed *= self.acceleration
                                       
class Picture(pygame.sprite.Sprite):
    def __init__(self, image, initpos):
        pygame.sprite.Sprite.__init__(self)
        self.image = image
        self.rect = self.image.get_rect()
        self.pos = initpos
        self.rect.midbottom = self.pos
    def update(self):
        return

class Doctor(pygame.sprite.Sprite):
    def __init__(self, directory, img_list, initpos, directory2):
        pygame.sprite.Sprite.__init__(self)
        self.cur_image = 1
        self.image_list = img_list
        self.directory = directory
        self.image = functions.load_image(self.directory + self.image_list[self.cur_image], -1)
        self.rect = self.image.get_rect()
        self.pos = initpos
        self.rect.midbottom = self.pos
        self.action = None
        self.delay = 200
        self.cur_behaviour = 0
        self.time = pygame.time.get_ticks()
        self.has_book = False
        self.sound_fx = pygame.mixer.Sound(directory2 + "\\voz_cientista.wav")
        self.sound_fx.set_volume(0.5)
    def update(self):
        if self.cur_behaviour == 0:
            self.talking()
        elif self.cur_behaviour == 1:
            self.get_book()
        elif self.cur_behaviour == 2:
            self.reading()
        elif self.cur_behaviour == 3:
            self.put_book_away()
        elif self.cur_behaviour == 4:
            self.standing()
        elif self.cur_behaviour == 5:
            self.win()
        elif self.cur_behaviour == 6:
            self.lose()
    def standing(self):
        if self.balloon.alive():
            self.cur_behaviour = 1
        else:
            self.cur_image = 0
            self.image = functions.load_image(self.directory + self.image_list[self.cur_image], -1)
    def talking(self):
        if self.balloon.alive():
            if pygame.time.get_ticks() >= self.time + self.delay:
                self.cur_image = (self.cur_image % 2) + 1
                self.image = functions.load_image(self.directory + self.image_list[self.cur_image], -1)
                self.time = pygame.time.get_ticks()
        else:
            self.cur_image = 1
            self.cur_behaviour = 1
    def get_book(self):
        if self.balloon.alive():
            self.sound_fx.stop()
            self.sound_fx.play()
            if pygame.time.get_ticks() >= self.time + self.delay:
                self.cur_image = 5
                self.image = functions.load_image(self.directory + self.image_list[self.cur_image], -1)
                self.time = pygame.time.get_ticks()
                self.has_book = True
        if self.has_book:
            self.cur_image = 0
            self.cur_behaviour = 2
    def reading(self):
        if self.balloon.alive():
            if pygame.time.get_ticks() >= self.time + self.delay:
                self.cur_image = (self.cur_image % 2) + 9
                self.image = functions.load_image(self.directory + self.image_list[self.cur_image], -1)
                self.time = pygame.time.get_ticks()
        else:
            self.cur_behaviour = 3
    def put_book_away(self):
        if self.has_book:
            if pygame.time.get_ticks() >= self.time + self.delay:
                self.cur_image = 5
                self.image = functions.load_image(self.directory + self.image_list[self.cur_image], -1)
                self.time = pygame.time.get_ticks()
                self.has_book = False
        if not self.has_book:
            if pygame.time.get_ticks() >= self.time + self.delay:
                self.cur_image = 0
                self.cur_behaviour = 4
    def win(self):
        if pygame.time.get_ticks() >= self.time + self.delay:
            self.cur_image = (self.cur_image % 2) + 3
            self.image = functions.load_image(self.directory + self.image_list[self.cur_image], -1)
            self.time = pygame.time.get_ticks()
    def lose(self):
        self.delay = 75
        if self.cur_image <= 8:
            if pygame.time.get_ticks() >= self.time + self.delay:
                self.image = functions.load_image(self.directory + self.image_list[self.cur_image], -1)
                self.time = pygame.time.get_ticks()
                self.cur_image += 1
            self.rect.left -= 7
            self.rect.bottom += 3
                 
class BG_Animation(pygame.sprite.Sprite):
    def __init__(self, directory, image_list, initpos, i, center=False):
        pygame.sprite.Sprite.__init__(self)
        self.cur_image = 0
        self.directory = directory
        self.image_list = image_list
        self.image = functions.load_image(self.directory + self.image_list[self.cur_image], -1)
        self.rect = self.image.get_rect()
        if center:
            self.rect.center = initpos
        else:
            self.rect.topleft = initpos
        self.ident = i
        self.dir = 1
        self.time = pygame.time.get_ticks()
        if self.ident == 3:
            self.delay = 500
        else:
            self.delay = 100
    def update(self):
        if self.ident != 0 and self.ident != 5:
            if self.cur_image == len(self.image_list) - 1:
                self.dir = -1
            elif self.cur_image == 0:
                self.dir = 1
        else:
            if self.cur_image == len(self.image_list) - 1:
                self.cur_image = 0
        if pygame.time.get_ticks() >= self.time + self.delay:
            self.cur_image += self.dir
            self.image = functions.load_image(self.directory + self.image_list[self.cur_image], -1)
            self.time = pygame.time.get_ticks()
            if self.delay != 500 and self.ident == 3:
                self.delay = 500
            if self.ident == 3 and self.dir == 1:
                self.delay = 100

class Balloon(pygame.sprite.Sprite):
    def __init__(self, directory, img_list, doctor, current=0):
        pygame.sprite.Sprite.__init__(self)
        self.cur_image = current
        self.image_list = img_list
        self.directory = directory
        self.image = functions.load_image(self.directory + self.image_list[self.cur_image], -1)
        self.rect = self.image.get_rect()
        self.rect.midbottom = doctor.rect.midtop
        self.run_time = 4000
        self.delay = 30
        self.last_run = 0
        self.move = 0
        self.speed = 1
        self.time = pygame.time.get_ticks()
        doctor.balloon = self
    def update(self):
        if pygame.time.get_ticks() > self.last_run + self.delay:
            if self.move >= 8:
                self.speed = -1
            elif self.move <= 0:
                self.speed = 1
            self.rect.top += self.speed
            self.move += self.speed
            self.last_run = pygame.time.get_ticks()
        self.image = functions.load_image(self.directory + self.image_list[self.cur_image], -1)
    
class Funnel(pygame.sprite.Sprite):
    def __init__(self, rect):
        pygame.sprite.Sprite.__init__(self)
        self.rect = pygame.Rect(rect)

class Sequence():
    def __init__(self):
        self.current_loop = 0
        self.wanted_object = 0
        self.loop_size = [1, 2, 3, 4, 5, 7, 9, 11, 13, 16]
        self.sequence = [6, 1, 8, 7, 0, 3, 2, 3, 1, 9, 4, 6, 5, 8, 0, 1]
    def increase(self, ident):
        if ident == self.sequence[self.wanted_object]:
            if self.wanted_object == self.loop_size[self.current_loop]:
                self.current_loop += 1
                self.wanted_object = 0
                return
            else:
                self.wanted_object += 1
                return True
        else:
            return False
    def force_increase(self):
        if self.wanted_object == self.loop_size[self.current_loop]:
            self.current_loop += 1
            self.wanted_object = 0
            print "loop:", self.current_loop
            print "object:", self.wanted_object
        else:
            self.wanted_object += 1
            print "object:", self.wanted_object



class Clock():
    def __init__(self):
        self.value_sec = 0
        self.value_min = 0
        self.pos_sec = (750,0)
        self.time = pygame.time.get_ticks()
        self.delay = 1000
    def update(self):
        if pygame.time.get_ticks() > self.time + self.delay: 
            if self.value_sec < 59:
                self.value_sec += 1
                self.time = pygame.time.get_ticks()
            else:
                self.value_sec = 0
                self.value_min += 1
                self.time = pygame.time.get_ticks()
    